@@ -10,13 +10,14 @@ from .tokens import PdfTokens
 from .errors import PdfParseError
 from .pagemerge import PageMerge
 
-__version__ = '0.2'
+__version__ = '0.4'
 
 # Add a tiny bit of compatibility to pyPdf
 
 PdfFileReader = PdfReader
 PdfFileWriter = PdfWriter
 
-__all__ = [PdfWriter, PdfReader, PdfObject, PdfName, PdfArray,
-           PdfTokens, PdfParseError, PdfDict, IndirectPdfDict,
-           PdfString, PageMerge]
+__all__ = """PdfWriter PdfReader PdfObject PdfName PdfArray
+             PdfTokens PdfParseError PdfDict IndirectPdfDict
+             PdfString PageMerge""".split()
+
